@@ -9,8 +9,6 @@ from neosctl.auth import ensure_login
 from neosctl.util import process_response
 
 app = typer.Typer()
-secret_app = typer.Typer()
-app.add_typer(secret_app, name="secret", help="Manage secrets for a spark job.")
 
 
 def _spark_url(name: str, gateway_api_url: str) -> str:
@@ -590,136 +588,3 @@ def unstream_job(
 
     r = _request(ctx)
     process_response(r)
-
-
-@secret_app.command()
-def add(
-    ctx: typer.Context,
-    product_identifier: str = typer.Argument(..., help="Data Product identifier"),
-    secrets: typing.List[str] = typer.Option(..., "--secret", "-s", help="Secret in the form key:value"),
-) -> None:
-    """Add a set of secrets for a spark job."""
-
-    @ensure_login
-    def _request(ctx: typer.Context, payload: typing.Dict) -> httpx.Response:
-        return util.post(
-            ctx,
-            _secret_url(product_identifier, ctx.obj.gateway_api_url),
-            json=payload,
-        )
-
-    payload = {"data": {}}
-    for s in secrets:
-        name, value = s.split(":")
-        payload["data"][name] = value
-
-    r = _request(ctx, payload)
-
-    process_response(r)
-
-
-@secret_app.command()
-def update(
-    ctx: typer.Context,
-    product_identifier: str = typer.Argument(..., help="Data Product identifier"),
-    secrets: typing.List[str] = typer.Option(..., "--secret", "-s", help="Secret in the form key:value"),
-) -> None:
-    """Update existing secrets.
-
-    This will overwrite existing keys, and add new keys, any keys that already
-    exist but aren't provided will remain.
-    """
-
-    @ensure_login
-    def _request(ctx: typer.Context, payload: typing.Dict) -> httpx.Response:
-        return util.patch(
-            ctx,
-            _secret_url(product_identifier, ctx.obj.gateway_api_url),
-            json=payload,
-        )
-
-    payload = {"data": {}}
-    for s in secrets:
-        name, value = s.split(":")
-        payload["data"][name] = value
-
-    r = _request(ctx, payload)
-
-    process_response(r)
-
-
-@secret_app.command()
-def remove(
-    ctx: typer.Context,
-    product_identifier: str = typer.Argument(
-        ...,
-        help="Data Product identifier",
-        callback=util.sanitize,
-    ),
-) -> None:
-    """Remove secret."""
-
-    @ensure_login
-    def _request(ctx: typer.Context) -> httpx.Response:
-        return util.delete(
-            ctx,
-            _secret_url(product_identifier, ctx.obj.gateway_api_url),
-        )
-
-    r = _request(ctx)
-
-    process_response(r)
-
-
-@secret_app.command()
-def remove_key(
-    ctx: typer.Context,
-    product_identifier: str = typer.Argument(
-        ...,
-        help="Data Product identifier",
-        callback=util.sanitize,
-    ),
-    keys: typing.List[str] = typer.Option(
-        ...,
-        "--key",
-        "-k",
-        help="Key name you wish to remove from secret",
-        callback=util.sanitize,
-    ),
-) -> None:
-    """Remove a set of keys from a secret."""
-
-    @ensure_login
-    def _request(ctx: typer.Context) -> httpx.Response:
-        return util.delete(
-            ctx,
-            f"{_secret_url(product_identifier, ctx.obj.gateway_api_url)}/key",
-            json={"keys": keys},
-        )
-
-    r = _request(ctx)
-
-    process_response(r)
-
-
-@secret_app.command()
-def get(
-    ctx: typer.Context,
-    product_identifier: str = typer.Argument(
-        ...,
-        help="Data Product identifier",
-        callback=util.sanitize,
-    ),
-) -> None:
-    """Get existing secret keys."""
-
-    @ensure_login
-    def _request(ctx: typer.Context) -> httpx.Response:
-        return util.get(
-            ctx,
-            _secret_url(product_identifier, ctx.obj.gateway_api_url),
-        )
-
-    r = _request(ctx)
-
-    process_response(r)
